changeset 8604:43f831758d42

fix typo in fsolve
author Jaroslav Hajek <highegg@gmail.com>
date Tue, 27 Jan 2009 21:22:59 +0100
parents 4c68e26e3ba1
children 9fc72c114ce1
files scripts/optimization/fsolve.m
diffstat 1 files changed, 2 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/scripts/optimization/fsolve.m	Tue Jan 27 21:04:19 2009 +0100
+++ b/scripts/optimization/fsolve.m	Tue Jan 27 21:22:59 2009 +0100
@@ -102,8 +102,8 @@
   funvalchk = strcmpi (optimget (options, "FunValCheck", "off"), "on");
 
   if (funvalchk)
-    ## Replace fun with a guarded version.
-    fun = @(x) guarded_eval (fun, x);
+    ## Replace fcn with a guarded version.
+    fcn = @(x) guarded_eval (fcn, x);
   endif
 
   ## These defaults are rather stringent. I think that normally, user